PRINT N'Iniciando recompilación de la tabla [dbo].[EvaluationReviewCommitment]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_EvaluationReviewCommitment] (
    [VCC]                VARCHAR (50)  NOT NULL,
    [EvaluationReviewId] VARCHAR (50)  NOT NULL,
    [ID]                 VARCHAR (50)  CONSTRAINT [DF_EvaluationReviewCommitment_ID] DEFAULT (newid()) NOT NULL,
    [LargeInteractionId] VARCHAR (255) NOT NULL,
    [AgentId]            VARCHAR (50)  NOT NULL,
    [Commitment]         VARCHAR (50)  NULL,
    [CreatedDate]        DATETIME      NULL,
    [CreatedUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]   DATETIME      NULL,
    [LastModifiedUserId] VARCHAR (50)  NULL,
    [Timestamp]          DATETIME      NULL
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[EvaluationReviewCommitment])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_EvaluationReviewCommitment] ([VCC], [EvaluationReviewId], [LargeInteractionId], [AgentId], [Commitment], [CreatedDate], [CreatedUserId], [LastModifiedDate], [LastModifiedUserId], [Timestamp])
        SELECT [VCC],
               [EvaluationReviewId],
               [LargeInteractionId],
               [AgentId],
               [Commitment],
               [CreatedDate],
               [CreatedUserId],
               [LastModifiedDate],
               [LastModifiedUserId],
               [Timestamp]
        FROM   [dbo].[EvaluationReviewCommitment];
    END

DROP TABLE [dbo].[EvaluationReviewCommitment];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_EvaluationReviewCommitment]', N'EvaluationReviewCommitment';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Modificando [dbo].[SaveEvaluationReviewCommitment]...';


GO
ALTER PROCEDURE [dbo].[SaveEvaluationReviewCommitment] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationReviewId VARCHAR(50) = NULL,
	@Id VARCHAR(50) = NULL,
	@LargeInteractionId VARCHAR(255) = NULL,
	@AgentId VARCHAR(50) = NULL,
	@Commitment VARCHAR(500) = NULL,
	@SaveUserId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ACTUALIZAMOS EL REGISTRO CORRESPONDIENTE A LA REVISION
	UPDATE [dbo].[EvaluationReviewCommitment]
		SET [Commitment] = @Commitment,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedUserId] = @SaveUserId,
			[Timestamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationReviewId] = @EvaluationReviewId
			AND [ID] = @Id
			
	-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
	IF @@ROWCOUNT = 0
	BEGIN
		-- 
		INSERT INTO [dbo].[EvaluationReviewCommitment] (
				[VCC],
				[EvaluationReviewId],
				[LargeInteractionId],
				[AgentId],
				[Commitment],
				[CreatedDate],
				[CreatedUserId],
				[Timestamp]
			) VALUES (
				@VCC,
				@EvaluationReviewId,
				@LargeInteractionId,
				@AgentId,
				@Commitment,
				GETUTCDATE(),
				@SaveUserId,
				GETUTCDATE()
			)
	END

	-- 
    SELECT 1 AS 'result'
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[CreateVcc]...';


GO
ALTER PROCEDURE [dbo].[CreateVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId   VARCHAR(50) = NULL,
	@DeleteDataDays         INT = 360
	)
AS
BEGIN
	SET NOCOUNT ON
	BEGIN TRY
    BEGIN TRANSACTION


	INSERT INTO [dbo].[VCC] (
			[VCC], 
			[ID], 
			[Description], 
			[Type], 
			[Country], 
			[TranscriptionDefaultLanguage], 
			[CognitiveEngine], 
			[Language],
			[TimeZone], 
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[DeleteDataDays], 
			[TimeStamp]
			)
	VALUES (
			@VCC, 
			@ID, 
			@Description, 
			@Type, 
			@Country, 
			@TranscriptionDefaultLanguage, 
			@CognitiveEngine, 
			@Language, 
			@TimeZone, 
			@CreatedDate,  
			@CreatedByUserId, 
			@LastModifiedDate, 
			@LastModifiedByUserId, 
			@DeleteDataDays,
			GETUTCDATE()
		)
	
	DECLARE @VCC_SYSTEM       VARCHAR(50) = 'system'

    --INSERTAR ROLES
	
	DECLARE @ROLES TABLE(
    [ID]            VARCHAR(50),
    [Description]   VARCHAR(50),
	[CreatedDate]   DATETIME,
    [CreatedByUserId] VARCHAR(50),
    [LastModifiedDate] DATETIME,
    [LastModifiedByUserId] VARCHAR(50),
	[SystemRole]    BIT,
    [Type]                 VARCHAR(50)
	)
	INSERT INTO @ROLES EXEC [dbo].[GetRoles] @VCC_SYSTEM,'name',''

	IF(EXISTS(SELECT [ID] FROM @ROLES))
	BEGIN
			INSERT INTO [dbo].[Role] (
					[VCC],
					[ID], 
					[Description],
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate],
					[LastModifiedByUserId],
					[SystemRole],
					[Type],
					[TimeStamp]
					)
			SELECT @VCC,
				   [ID],
				   [Description],
				   GETUTCDATE(), 
				   [CreatedByUserId],
				   GETUTCDATE(),
				   [LastModifiedByUserId],
				   [SystemRole],
				   [Type],
				   GETUTCDATE()
			FROM @ROLES
     END
	 ELSE
	 BEGIN
	       RAISERROR('SERVER_ERROR_ROLES_NOT_FOUND', 16, 16)
	 END

	--INSERTAR PERMISOS PARA LOS ROLES

	DECLARE @CountLicense INT = 0
	DECLARE @License      VARCHAR(50)
	
	DECLARE @ROLE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)
	DECLARE @ROUTE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [Route]   VARCHAR(250),
	 [Level]   VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)

	SET @CountLicense = (SELECT COUNT(*) FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	
	IF(@CountLicense>1)
	BEGIN
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,''
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM
	END

	IF(@CountLicense=1)
	BEGIN
	    SET @License = (SELECT Product FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,'', @License
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM,'', @License
	END
	
	INSERT INTO [dbo].[RolePermission] (
			    [VCC], 
				[RoleId], 
				[GroupId],
			    [TimeStamp]
			    ) 
				SELECT 
				@VCC,
				[ID],
				[GroupId],
			    GETUTCDATE()
				FROM @ROLE_PERMISSIONS

	INSERT INTO [dbo].[RoutePermission] (
			[VCC], 
			[ID], 
			[GroupId],
			[Route], 
			[Level], 
			[TimeStamp]
			)
			SELECT 
			@VCC,
			[ID],
			[GroupId],
			[Route],
			[Level],
			GETUTCDATE()
			FROM @ROUTE_PERMISSIONS


    --INSERTAR GRUPOS DE PERMISOS PARA LOS ROLES
	DECLARE @ROLE_PERMISSIONS_GROUP TABLE(
	 [Category] VARCHAR(50),
	 [GroupId]  VARCHAR(200),
	 [Type]     VARCHAR(50)
	)

	INSERT INTO @ROLE_PERMISSIONS_GROUP EXEC [dbo].[GetRolePermissionsGroups] @VCC_SYSTEM

	INSERT INTO [dbo].[RolePermissionsGroup] (
			                              [VCC], 
										  [GroupId], 
										  [Category], 
										  [Type], 
										  [TimeStamp]
										  )
		                                 SELECT 
										 @VCC, 
										 GroupId,
										 Category,
										 [Type], 
										 GETUTCDATE()	
										 FROM @ROLE_PERMISSIONS_GROUP

    --INSERTAR FEELINGS
	INSERT INTO [dbo].[Feeling] (
			                   [VCC], 
							   [Name], 
							   [Description],
							   [CreatedDate], 
							   [CreatedByUserId], 
							   [LastModifiedDate], 
							   [LastModifiedByUserId], 
							   [TimeStamp]
							   )
							   SELECT
							   @VCC,
							   [Name],
							   [Description],
							   GETUTCDATE(),
							   [CreatedByUserId],
							   GETUTCDATE(),
							   [LastModifiedByUserId],
							   GETUTCDATE()	
							   FROM [dbo].[Feeling] (NOLOCK)
							   WHERE [VCC] = @VCC_SYSTEM

    --INSERTAR PROGRAMACION NEUROLINGUISTICA
	INSERT INTO [dbo].[NeuroLinguisticProgramming] (
								[VCC],
								[Name],
								[Description],
								[CreatedDate],
								[CreatedByUserId],
								[LastModifiedDate], 
								[LastModifiedByUserId],
								[TimeStamp]
								)
								SELECT 
								@VCC,
								[Name],
								[Description],
								GETUTCDATE(),
								[CreatedByUserId],
								GETUTCDATE(),
								[LastModifiedByUserId],
								GETUTCDATE()
								FROM [dbo].[NeuroLinguisticProgramming] (NOLOCK)
								WHERE [VCC] = @VCC_SYSTEM
		
   --INSERTAR PALABRAS

   IF(EXISTS(SELECT [Name] FROM [dbo].[Word] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
   BEGIN
		   INSERT INTO [dbo].[Word](
					[VCC],
					[NeuroLinguisticProgrammingId],
					[Name],
					[ProcessId],
					[Language],
					[Type],
					[CreatedDate],
					[CreatedByUserId],
					[LastModifiedDate],
					[LastModifiedByUserId],
					[TimeStamp]
					)
				SELECT
				@VCC,
				[NeuroLinguisticProgrammingId],
				[Name],
				[ProcessId],
				[Language],
				[Type],
				GETUTCDATE(),
				[CreatedByUserId],
				GETUTCDATE(),
				[LastModifiedByUserId],
				GETUTCDATE()
			   FROM [dbo].[Word] (NOLOCK)
			   WHERE [VCC] = @VCC_SYSTEM
   END
   ELSE
   BEGIN
	       RAISERROR('SERVER_ERROR_WORD_NOT_FOUND', 16, 16)
   END

   --INSERTAR CATEGORIAS
   INSERT INTO [dbo].[Category] (
			[VCC], 
			[Name], 
			[Description],
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp]
			)
		SELECT 
		@VCC,
		[Name],
		[Description],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		GETUTCDATE()
	FROM [dbo].[Category] (NOLOCK)
	WHERE [VCC] = @VCC_SYSTEM

	--INSERTAR AMBIENTES
	IF(@Type <> 'OTHER')
	BEGIN
		DECLARE @NAME VARCHAR(100)
		SELECT @NAME = [Word] FROM [dbo].[WordsByLanguage] (NOLOCK) WHERE [Language] = @Language AND [Label] = 'ENVIRONMENT' 
		
		-- DECLARAMOS UNA VARIABLE PARA SETTEAR EL TIPO DE AMBIENTE INTEGRADO PARA EL VCC
		DECLARE @VCC_TYPE VARCHAR(25) = NULL
		IF (@Type = 'ALLEGRO' OR @Type = 'OCC') SET @VCC_TYPE = 'allegro'
		ELSE IF @Type = 'I6' SET @VCC_TYPE = 'i6'
		
		INSERT INTO [dbo].[Environment] (
			[VCC], 
			[Name], 
			[Type],
			[Description],
			[FTPDirectory],
			[ApiHost],
			[ApiPort],
			[ApiUser],
			[DbDisabled],
			[DbServer],
			[DbPort],
			[DbUser], 
			[PbxDisabled],
			[PbxServer],
			[PbxPort],
			[PbxUser],
			[ApiPassword],
			[DbPassword],
			[PbxPassword],
			[CreatedDate],
			[CreatedByUserId],
			[TimeStamp]
		)
			SELECT @VCC,
					@NAME,
					[Type],
					@NAME,
					[FTPDirectory],
					[ApiHost],
					[ApiPort],
					[ApiUser],
					[DbDisabled],
					[DbServer],
					[DbPort],
					[DbUser],
					[PbxDisabled],
					[PbxServer]	,
					[PbxPort],
					[PbxUser],
					[ApiPassword],
					[DbPassword],
					[PbxPassword],
					GETUTCDATE(),
					[CreatedByUserId],
					GETUTCDATE()
				FROM [dbo].[Environment] (NOLOCK)
				WHERE [VCC] = @VCC_SYSTEM
					AND [Type] = @VCC_TYPE

	END


	--INSERTAR PERMISOS PARA CATEGORIAS

	INSERT INTO [dbo].[CategoryPermissions](
			[VCC], 
			[Category], 
			[Position], 
			[TimeStamp]
			)
			SELECT
			@VCC,
		    [Category],
			[Position],
			GETUTCDATE()
			FROM [dbo].[CategoryPermissions] (NOLOCK) 
			WHERE [VCC] = @VCC_SYSTEM
			GROUP BY [Category],[Position]
		  

   --INSERTAR TENANT

   DECLARE @TENANT TABLE(
    [TenantId]     VARCHAR(50),
    [ClientId]     VARCHAR(50),
    [ClientSecret] VARCHAR(50),
    [Resource]     VARCHAR(50)
	)
	
	INSERT INTO @TENANT EXEC [dbo].[GetTenantVCCByVCC] @VCC_SYSTEM
	IF(EXISTS(SELECT [TenantId] FROM @TENANT))
	BEGIN

		INSERT INTO [dbo].[TenantVCC](
		[VCC], 
		[TenantId], 
		[ClientId], 
		[ClientSecret], 
		[Resource], 
		[CreatedDate], 
		[CreatedByUserId], 
		[TimeStamp])
		SELECT 
		@VCC,
		[TenantId],
		[ClientId],
		[ClientSecret],
		[Resource],
		GETUTCDATE(),
		@CreatedByUserId,
		GETUTCDATE()
		FROM @TENANT

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_TENANT_NOT_FOUND', 16, 16)
	END

	--INSERTAR NLU

	IF(EXISTS(SELECT [Name] FROM [dbo].[NLU] WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM))
	BEGIN
		INSERT INTO [dbo].[NLU] (
					[VCC], 
					[Name], 
					[Culture],
					[Description], 
					[AppId], 
					[SubscriptionKey],
					[IsSystemApp], 
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate], 
					[LastModifiedByUserId], 
					[TimeStamp],
					[CognitiveEngine]
					)
					SELECT
					@VCC,
					[Name], 
					[Culture],
					[Description], 
					CONCAT(@VCC,'::',[Name]), 
					[SubscriptionKey],
					[IsSystemApp], 
					GETUTCDATE(), 
					[CreatedByUserId], 
					GETUTCDATE(), 
					[LastModifiedByUserId], 
					GETUTCDATE(),
					'RASA'
					FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM

        INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@VCC,
			'Agent',
			'Agent',
			CONCAT(@VCC,'::',[Name]),
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_SYSTEM_APPS_SAVING_FAILED', 16, 16)
	END

	--INSERTAR DICCIONARIOS

	IF(EXISTS(SELECT [Name] FROM [dbo].[Dictionary] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN 
	INSERT INTO [dbo].[Dictionary] (
			[VCC], 
			[Name], 
			[Description], 
			[Language], 
			[IsSystemDictionary], 
			[CreatedDate], 
			[CreatedByUserId], 
			[TimeStamp]
		)
		SELECT
		    @VCC,
		    [Name],
			[Description],
			[Language],
			[IsSystemDictionary],
			GETUTCDATE(),
			[CreatedByUserId],
			GETUTCDATE()
		FROM [dbo].[Dictionary] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	    RAISERROR('SERVER_ERROR_SYSTEM_DICTIONARIES_SAVING_FAILED',16,16)
	END

	--INSERTAR TIPOS DE INTERACCIONES
	IF(EXISTS(SELECT [ID] FROM [dbo].[InteractionType] WHERE [Instance] = @VCC_SYSTEM ))
	BEGIN
	INSERT INTO [dbo].[InteractionType] (
			[Instance],
			[ID],
			[Description]
			)
			SELECT
			@VCC,
			[ID],
		    [Description]
			FROM InteractionType  (NOLOCK)
			WHERE [Instance] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_INTERACTION_TYPE_NOT_FOUND',16,16) 
	END

	--INSERTAR GENERIC QUERY

	IF(EXISTS(SELECT [Name] FROM [dbo].[GenericQuery] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [dbo].[GenericQuery]
		(
			[VCC],
			[Name],
			[Description],
			[Query],
			[RawData],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId],
			[Version],
			[TimeStamp]
		)
		SELECT
		@VCC,
		[Name],--REPLACE([Name], @Language+'_', ''),
		[Description],
		[Query],
		[RawData],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		[Version],
		GETUTCDATE()
		FROM [dbo].[GenericQuery] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM --AND [Name] LIKE @Language + '%'
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_GENERIC_QUERY_NOT_FOUND',16,16) 
	END

	--INSERTAR  USUARIO AUDITOR SPEECH
	EXEC [dbo].[SaveSpeechAnalyticAuditorUser] @VCC

	--INSERTAR REPORTES
	IF(EXISTS(SELECT [ID] FROM  [dbo].[Report] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [Report] (
			[VCC], 
			[ID], 
			[Description],
			[Type],
            [Procedure], 
			[StartDate],
			[EndDate],
            [Frecuency],
			[HourSpace],
			[ExactTime],
            [Weekday],
			[DayMonth],
			[Summary],
            [Filter], 
			[Email], 
			[CreatedDate],
            [CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
            [TimeStamp]
        )
		SELECT
		        @VCC,
				[ID],
				[Description],
				[Type],
				[Procedure],
				[StartDate],
				[EndDate],
				[Frecuency],
				[HourSpace],
				[ExactTime],
				[Weekday],
				[DayMonth],
				[Summary],
				[Filter],
				[Email],
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE()
			FROM [dbo].[Report] (NOLOCK)
			WHERE [VCC] = @VCC_SYSTEM

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_REPORT_NOT_FOUND',16,16) 
	END

	COMMIT TRANSACTION

    END TRY

    BEGIN CATCH

    IF @@TRANCOUNT > 0 
	BEGIN
		ROLLBACK TRANSACTION
		--ELIMINAR LOS REGISTROS SI HA FALLADO
		EXEC [dbo].[RollbackVcc] @VCC
	END

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
  
    END CATCH
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluations]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluations] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
	@IdEvaluationPlan VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionCoached VARCHAR(50) = NULL,
	@InteractionIds     VARCHAR(MAX) = NULL,
	@EvaluationsLimit Int = 0
)
AS
BEGIN
	SET NOCOUNT ON
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';
	
	-- SI ORIGINS TIENE DOS VALORES, IGNORAMOS EL FILTRO
	IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 SET @InteractionOrigins = ''
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	-- EMULAMOS UNA NUEVA TABLA EN BASE A INTERACTIONEVALUATIONPLAN
	SET @SQL_SELECT_1 += '
		;WITH CTE AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction], 
					ER.[IdAgent],
					IEP.[AgentName],
					RN = ROW_NUMBER() OVER(PARTITION BY IEP.[Instance], IEP.[IdEvaluationPlan], IEP.[IdInteraction] ORDER BY IEP.[CreatedDate] ASC)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = ER.[Instance]
						AND EP.[Id] =  ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON (AEP.[Instance] = ER.[Instance] 
						AND AEP.[IdAuditor] = ER.[IdAuditor] 
						AND AEP.[IdInteraction] = ER.[IdInteraction] 
						AND AEP.[InteractionType] = ER.[InteractionType] 
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
				INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
					ON IEP.[Instance] = ER.[Instance] 
						AND IEP.[IdEvaluationPlan] = EP.[ID]
						AND IEP.[IdInteraction] = ER.[IdInteraction]
						AND IEP.[IdAgent] = ER.[IdAgent]
				WHERE ER.[Instance] = ''' + @Instance + '''
					AND ER.[EvaluationDate] BETWEEN ''' + @EvaluationDateFrom + '''AND ''' + @EvaluationDateTo + '''
					AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
					AND AEP.[Completed] = 1
		) '

	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				AEP.Completed						''completed'',
				AEP.[StatusDescription]             ''statusDescription'',
				A.[ErrorMessage]                    ''errorMessage'',
    			AEP.score							''qualification'',
    			AEP.IdAuditor						''idAuditor'',
    			U.FirstName + '' '' + U.LastName	''auditorName'',
    			MAX(ER.EvaluationDate)				''evaluationDate'',
    			AEP.IdEvaluationPlan				''idEvaluationPlan'',
				EP.Description						''evaluationPlan'',
    			AEP.idAgent							''idAgent'',
    			C.[AgentName]						''agentName'',							-- NOMBRE DEL AGENTE
				AEP.idInteraction					''idInteraction'',
				AEP.InteractionDate					''interactionDate'',
    			AEP.InteractionType					''interactionType'',
    			AEP.IdCampaign						''idCampaign'',
				COUNT(ERC.[Id])						''commitments'' '

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) 
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK) 
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdAuditor] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
			LEFT JOIN [dbo].[EvaluationReview] ERE (NOLOCK)
				ON ERE.[VCC] = AEP.[Instance] 
					AND ERE.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERE.[InteractionId] = AEP.[IdInteraction]
					AND ERE.[SupervisorId] = AEP.[IdAuditor] 
			LEFT JOIN [dbo].[EvaluationReviewCommitment] ERC (NOLOCK)
				ON ERC.[VCC] = AEP.[Instance] 
					AND ERC.[EvaluationReviewId] = ERE.[Id]
					AND ERC.[AgentId] = AEP.[idAgent]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
			    ON A.[VCC] = AEP.[Instance]
			        AND A.[ID] = AEP.[IdInteraction]
			LEFT JOIN [User] U (NOLOCK) 
				ON (U.[VCC] = ER.[Instance] 
					AND U.ID = AEP.IdAuditor) 
			LEFT JOIN CTE C (NOLOCK) 
				ON C.[Instance] = ER.[Instance]
					AND C.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND C.[IdInteraction] = ER.[IdInteraction] 
					AND C.[IdAgent] = ER.[IdAgent] 
					AND C.RN = 1 '

	SET @FILTERS_FIXED_PART = '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND ER.[EvaluationDate] >= ''' + @EvaluationDateFrom + '''
				AND ER.[EvaluationDate] <= ''' + @EvaluationDateTo + '''
				AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
				AND AEP.[Completed] = 1 ' -- LINEA PARA FILTRAR EVALUACIONES COMPLETADAS

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) '
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@IdEvaluationPlan IS NOT NULL AND @IdEvaluationPlan != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @IdEvaluationPlan + ''','','')) '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	--IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  '
	END;
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL '
	END
	
	--IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '

	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = ''
	    SET @FILTERS_EXCLUDING_PART += ' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
	END

	SET @SQL_EXTRA += '
			GROUP BY AEP.Completed,
						AEP.[StatusDescription],
						A.[ErrorMessage],
						AEP.score,
						AEP.IdAuditor,
						U.FirstName + '' '' + U.LastName,
						AEP.IdEvaluationPlan,
						EP.Description,
						AEP.idAgent,
						C.[AgentName],
						AEP.idInteraction,
						AEP.InteractionDate,
						AEP.InteractionType,
						AEP.IdCampaign '

	IF @InteractionCoached IS NOT NULL AND @InteractionCoached != ''
	BEGIN
		IF @InteractionCoached = 'true'
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) >= 1 '
		ELSE 
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) = 0 '
	END

	SET @SQL_EXTRA += '
			ORDER BY MAX(ER.EvaluationDate) DESC '

	SET @SQL_SELECT_1 += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA 

	-- SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Modificando [dbo].[GetGenericQueries]...';


GO
ALTER PROCEDURE [dbo].[GetGenericQueries]
(
	@VCC								VARCHAR(50) = NULL,
	@SearchCriteria						VARCHAR(50) = NULL,
	@SearchExpression					VARCHAR(50) = NULL,
	@StartDate							DATETIME,
	@EndDate							DATETIME
)
AS
BEGIN

	DECLARE @CURRENT_LANGUAGE varchar(2)
	SELECT @CURRENT_LANGUAGE = [language] from [dbo].[VCC] where [VCC] =@VCC
	
	
	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
	SET NOCOUNT ON

	
	SELECT GQ.[VCC]							''vcc'',
		GQ.[Name]							''name'',
		GQ.[Description]					''description'',
		GQ.[Query]							''query'',
		GQ.[RawData]						''rawData'',
		GQ.[CreatedDate]					''createdDate'',
		GQ.[CreatedByUserId]				''createdByUserId'',
		GQ.[LastModifiedDate]				''lastModifiedDate'',
		GQ.[LastModifiedByUserId]			''lastModifiedByUserId'',
		GQ.[Version]                        ''version'' 
		FROM GENERICQUERY (NOLOCK) GQ
		INNER JOIN 
		( SELECT * FROM GenericQuery (NOLOCK) WHERE VCC =''SYSTEM'' AND [Name] LIKE ' +''''+ @CURRENT_LANGUAGE + '%'+'''
		) AS GS 
		ON GQ.[Name] = GS.[Name]	

	WHERE  GQ.[VCC]='''+@VCC+''' 

	UNION ALL


	SELECT
		[VCC]							''vcc'',
		[Name]							''name'',
		[Description]					''description'',
		[Query]							''query'',
		[RawData]						''rawData'',
		[CreatedDate]					''createdDate'',
		[CreatedByUserId]				''createdByUserId'',
		[LastModifiedDate]				''lastModifiedDate'',
		[LastModifiedByUserId]			''lastModifiedByUserId'',
		[Version]                       ''version''
	FROM
		[dbo].[GenericQuery] (NOLOCK)
	WHERE
		[VCC] = ''' + @VCC + '''
		AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Query], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''query'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND [NAME] NOT IN (SELECT [NAME] FROM [dbo].[GenericQuery] WHERE VCC =''SYSTEM'')
		'
	
	IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
	BEGIN
		SET @SQL += '
			--AND CONVERT(VARCHAR(10), [CreatedDate], 120) BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
			AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
			
		'
	END
	SET @SQL += '
	ORDER BY [CreatedDate] DESC
	'
	SET NOCOUNT OFF
	--PRINT @SQL
	EXEC(@SQL)
END
GO
PRINT N'Modificando [dbo].[GetStudyResultSummary]...';


GO
ALTER PROCEDURE [dbo].[GetStudyResultSummary]
(
	@VCC					VARCHAR(50),
	@StudyId				VARCHAR(200),
	@NewStructure			VARCHAR(1)
)
AS
BEGIN
	SET NOCOUNT ON

	BEGIN
		SELECT
			B.[Name]						'processName',
			A.[Name]						'studyName',
			A.[Description]					'studyDescription',
			A.[TemplateId]					'templateId'
		FROM [dbo].[Study] A (NOLOCK)
		INNER JOIN Process B ON A.ProcessId = B.[Name]
		WHERE A.[VCC] = @VCC 
			AND A.[Name] = @StudyId
	END

	BEGIN
		SELECT
			[VCC]							'vcc',
			[StudyId]						'studyId',
			[TemplateId]					'templateId',
			[TemplateThemeId]				'templateThemeId',
			[ID]							'id',
			[Description]					'description',
			[Category1]						'category1',
			[Category2]						'category2',
			[Total]							'total',
			[Duration]						'duration',
			[Silence]						'silence',
			[Confidence]					'confidence',
			[CreatedDate]					'createdDate',
			[CreatedByUserId]				'createdByUserId',
			[LastModifiedDate]				'lastModifiedDate',
			[LastModifiedByUserId]			'lastModifiedByUserId'
		FROM [dbo].[StudyResultSummary] (NOLOCK)
		WHERE [VCC] = @VCC 
			AND [StudyId] = @StudyId
	END

	IF(@NewStructure IS NULL)
	BEGIN
		SELECT
			A.[TemplateThemeId]									'templateThemeId',
			A.[TemplateThemeItemId]								'templateThemeItemId',
			--ISNULL(D.[Query], A.[TemplateThemeItemId])			'query', -- Si es NULL se mostrara valor de TemplateThemeItem campo ID.
			ISNULL(ISNULL(D.[Query], E.[EntityName]),'')			'query', -- Si es NULL se mostrara valor de TemplateThemeItem campo ID.
			ISNULL(C.[Channel], AI.[Channel])					'interactionType',
			-- REPLACE(A.[TranscriptionId], '_0_1', '')			'transcriptionId',

			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN REPLACE(A.[TranscriptionId], '_0_1', '') 
				ELSE AI.[ID] END								'transcriptionId',

			C.[Section]											'section',
			C.[Part]											'part',
			AI.[Folder]											'folder',
			AI.[Campaign]										'campaign',
			--ISNULL(C.[Agent], '')								'agent'
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[Agent], '') 
				ELSE ISNULL(AI.[FirstTakedAgent], '') END		'agent',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsTranscribed], '') 
				ELSE ISNULL(AI.[IsTranscribed], '') END			'isTranscribed',
			CASE WHEN C.[Channel] IS NOT NULL
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsCancel], '') 
				ELSE ISNULL(AI.[IsCancel], '') END				'isCancel'
		FROM 
			[dbo].[StudyResultSummaryDetail] A (NOLOCK)
			INNER JOIN [dbo].[Study] S (NOLOCK) 
				ON S.[VCC] = A.[VCC] 
					AND S.[Name] = A.[StudyId]
			INNER JOIN [dbo].[HistoricTemplateThemeItem] B (NOLOCK) 
				ON S.[TemplateId] = B.[TemplateId] 
					AND A.[TemplateThemeId] = B.[TemplateThemeId] 
					AND A.[TemplateThemeItemId] = B.[ID]
					AND B.[StudyId] = S.[Name]
			
			LEFT JOIN [dbo].[Audio] C (NOLOCK)  -- (!)SE CAMBIO EL INNER POR LEFT PARA CONSIDER LAS TRANSCRIPCIONES DE CANALES ASINCRINOS
				ON A.[VCC] = C.[VCC]
					AND A.[TranscriptionId] = CONCAT(C.[ID], '_', C.[Section], '_', C.[Part])
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON S.[VCC] = PA.[VCC] 
					AND S.[ProcessId] = PA.[ProcessId] 
					AND A.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])

			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON A.[TranscriptionId] = CONCAT(AI.[Channel], '_', AI.[Campaign], '_', AI.[Folder], '_', REPLACE(AI.[ID], ':', '_'))
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = S.[VCC]
					AND PAI.[ProcessId] = S.[ProcessId]
					AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', REPLACE(PAI.[InteractionId], ':', '_')) = A.[TranscriptionId]

			LEFT JOIN [dbo].[GenericQuery] D (NOLOCK) 
				ON B.[VCC] = D.[VCC] 
					AND  B.[ID] = D.[Name] -- Se agrega LEFT JOIN para poder mostrar.

			LEFT JOIN [dbo].[TemplateThemeItemEntity] E 
				ON A.TemplateThemeId = E.TemplateThemeId
		WHERE
			B.[VCC] IN ('system', @VCC) AND
			A.[StudyId] = @StudyId
	END
	ELSE
	BEGIN
		-- ESTE BLOQUE NUNCA SE USA, EL UNICO LLAMADO DE LA FUNCION INSERTA DIRECTAMENTE NULL PARA LA VARIABLE @NewStructure
		SELECT
			A.[TemplateThemeId]									'templateThemeId',
			A.[TemplateThemeItemId]								'templateThemeItemId',
			D.[Query]											'query',
			ISNULL(C.[Channel], AI.[Channel])					'interactionType',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN A.[TranscriptionId] 
				ELSE AI.[ID] END								'transcriptionId',
			C.[Section]											'section',
			C.[Part]											'part',
			AI.[Folder]											'folder',
			AI.[Campaign]										'campaign',
			--ISNULL(C.[Agent], '')								'agent',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[Agent], '') 
				ELSE ISNULL(AI.[FirstTakedAgent], '') END		'agent',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsTranscribed], '') 
				ELSE ISNULL(AI.[IsTranscribed], '') END			'isTranscribed',
			CASE WHEN C.[Channel] IS NOT NULL
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsCancel], '') 
				ELSE ISNULL(AI.[IsCancel], '') END				'isCancel'
			
		FROM 
			[dbo].[StudyResultSummaryDetail] A (NOLOCK)
			INNER JOIN [dbo].[Study] S (NOLOCK) 
				ON S.[VCC] = A.[VCC] 
					AND S.[Name] = A.[StudyId]
			INNER JOIN [dbo].[HistoricTemplateThemeItem] B (NOLOCK) 
				ON S.[TemplateId] = B.[TemplateId] 
					AND A.[TemplateThemeId] = B.[TemplateThemeId] 
					AND A.[TemplateThemeItemId] = B.[ID]
					AND B.[StudyId] = S.[Name]
			
			LEFT JOIN [dbo].[Audio] C (NOLOCK) 
				ON A.[VCC] = C.[VCC]
					AND A.[TranscriptionId] = CONCAT(C.[ID], '_', C.[Section], '_', C.[Part])
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON S.[VCC] = PA.[VCC] 
					AND S.[ProcessId] = PA.[ProcessId] 
					AND A.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
			
			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON A.[TranscriptionId] = CONCAT(AI.[Channel], '_', AI.[Campaign], '_', AI.[Folder], '_', REPLACE(AI.[ID], ':', '_'))
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = S.[VCC]
					AND PAI.[ProcessId] = S.[ProcessId]
					AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', REPLACE(PAI.[InteractionId], ':', '_')) = A.[TranscriptionId]

			INNER JOIN [dbo].[GenericQuery] D (NOLOCK) 
				ON B.[VCC] = D.[VCC] 
					AND  B.[ID] = D.[Name]
		WHERE
			B.[VCC] IN ('system', @VCC) AND
			A.[StudyId] = @StudyId
	END
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetTemplates]...';


GO
--exec [GetTemplates] 'system','template','name',''
ALTER PROCEDURE [dbo].[GetTemplates] (
	@VCC Varchar(50) = NULL,	
	@Type Varchar(50) = NULL,	
	@SearchCriteria Varchar(50) = NULL,	
	@SearchExpression Varchar(50) = NULL,
	@Language VARCHAR(5) = 'en'
	)
AS
BEGIN
	SET NOCOUNT ON;

	-- CREAMOS LAS CTE QUE USAREMOS PARA RECUPERAR LOS MODELOS DE LAS PLANTILLAS
	WITH CTE_TEMPLATE_NLUS AS (
		SELECT DISTINCT TTI.[VCC]
						, TTI.[TemplateId]
						--, TTI.[TemplateThemeId]
						--, TTI.[ID]
						, N.[AppID]
						, N.[Name]
						, N.[Culture]
			FROM [TemplateThemeItem] TTI (NOLOCK)
			LEFT JOIN [dbo].[GenericQuery] GQ (NOLOCK) 
				ON GQ.[VCC] = TTI.[VCC]
					AND GQ.[Name] = TTI.[ID] 
					AND GQ.[VCC] = TTI.[VCC]
			INNER JOIN [dbo].[NLU] N (NOLOCK) 
				ON N.[VCC] = TTI.[VCC] 
					AND N.[Name] = SUBSTRING(TTI.[ID], 0, CHARINDEX('|', TTI.[ID]))
			WHERE TTI.[VCC] IN (@VCC, 'system')
				AND TTI.[ID] LIKE '%|%'
				AND GQ.[Query] IS NULL
	),
	TEMP_TEMPLATE AS(

	SELECT
		T.[Type]																'type',
		T.[Name]																'name',
		T.[Description]															'description',
		T.[Template]															'template',
		T.[Category]															'category',
		STUFF((
			SELECT ',' + CTN_INNER.[Culture]
				FROM CTE_TEMPLATE_NLUS CTN_INNER (NOLOCK)
				WHERE CTN_INNER.[TemplateId] = T.[Name]
		FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
		T.[CreatedDate]															'createdDate',
		T.[CreatedByUserId]														'createdByUserId',
		T.[LastModifiedDate]													'lastModifiedDate',
		T.[LastModifiedByUserId]												'lastModifiedByUserId'
	FROM [Template] T (NOLOCK)
	WHERE T.[VCC] IN (@VCC)
		AND T.[Type] = CASE WHEN ISNULL(@Type, '') = '' THEN T.[Type] ELSE @Type END
		AND T.[Type] IN ('custom')
		AND ISNULL(T.[Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Category], '') LIKE CASE WHEN @SearchCriteria = 'category' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
		
		UNION 
		
		SELECT
		T.[Type]																'type',
		T.[Name]																'name',
		T.[Description]															'description',
		T.[Template]															'template',
		T.[Category]															'category',
		STUFF((
			SELECT ',' + CTN_INNER.[Culture]
				FROM CTE_TEMPLATE_NLUS CTN_INNER (NOLOCK)
				WHERE CTN_INNER.[TemplateId] = T.[Name]
		FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
		T.[CreatedDate]															'createdDate',
		T.[CreatedByUserId]														'createdByUserId',
		T.[LastModifiedDate]													'lastModifiedDate',
		T.[LastModifiedByUserId]												'lastModifiedByUserId'
	FROM [Template] T (NOLOCK)
	WHERE T.[VCC] IN ('system')
		AND T.[Type] = CASE WHEN ISNULL(@Type, '') = '' THEN T.[Type] ELSE @Type END
		AND T.[Type] IN ('system')
		AND T.[Name] LIKE @Language+'%'
		AND ISNULL(T.[Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Category], '') LIKE CASE WHEN @SearchCriteria = 'category' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
		)

		SELECT * FROM TEMP_TEMPLATE WHERE [NAME] NOT LIKE 'qty_%' 
		ORDER BY [Name] asc, [CreatedDate] desc 
		
	--ORDER BY T.[Name] asc, T.[CreatedDate] desc 

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveCognitiveEngineMigrateStatus]...';


GO


ALTER PROCEDURE [dbo].[SaveCognitiveEngineMigrateStatus]
(
	@VCC	          VARCHAR(50),
	@Model            VARCHAR(50),
	@Key              VARCHAR(100),
	@Status           INT,
	@StatusCode       VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	--ACTUALIZAR EL ESTADO DE MIGRACION
    IF(@Model = '*')
    BEGIN 
          UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status WHERE [VCC] = @VCC AND [IsSystemApp] = 0 AND [Status] <> 4
          UPDATE I SET I.[StatusCode] = @StatusCode, I.[Status] = @Status FROM [dbo].[Intent] I JOIN [dbo].[NLU] N 
          ON (I.[VCC] = N.[VCC] AND I.[AppId] = N.[AppId])  WHERE I.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND I.[Status] <> 4
          UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status WHERE [VCC] = @VCC AND [Status] <> 4
          
          UPDATE U SET U.[StatusCode] = @StatusCode, U.[Status] = @Status FROM [dbo].[Utterance] U JOIN [dbo].[NLU] N 
          ON (U.[VCC] = N.[VCC] AND U.[AppId] = N.[AppId]) WHERE U.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND U.[Status] <> 4
    END--END MODEL * 
    ELSE 
    BEGIN --NLU
    	 IF(@Model = 'nlu')
			  BEGIN
			  	-- STATUS 4 SIGNIFICA QUE ESTA CANCELADO POR VARIOS INTENTOS ERRONEOS
				 IF(@Key = '*')
				 UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status WHERE [VCC] = @VCC AND [IsSystemApp] = 0 AND [Status] <> 4
				 ELSE
				 BEGIN 
				  IF(@Key = 'AVAILABLE')
				    --ACTUALIZA A DISPONIBLE TODOS LOS QUE MIGRARON
				    UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status  WHERE [VCC] = @VCC AND [Status] = 8 AND [IsSystemApp] = 0
				  ELSE
				    UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status  WHERE [VCC] = @VCC AND [Name] = @key AND [IsSystemApp] = 0
				 END
				 
			  END
		  ELSE 
		   BEGIN --INTENT
		   
			  IF(@Model = 'intent')
			    BEGIN 
			    
			     IF(@Key = '*')
				  UPDATE I SET I.[StatusCode] = @StatusCode, I.[Status] = @Status FROM [dbo].[Intent] I JOIN [dbo].[NLU] N 
                  ON (I.[VCC] = N.[VCC] AND I.[AppId] = N.[AppId])  WHERE I.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND I.[Status] <> 4
				 ELSE
				 UPDATE [dbo].[Intent] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [IntentId] = @key 
				 
			     END
			   ELSE
			     BEGIN --ENTITY
			       
				    IF(@Model = 'entity')
				    BEGIN 
				    
					     IF(@Key = '*')
						 UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status WHERE [VCC] = @VCC AND [Status] <> 4
						 ELSE
						 UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [ID] = @key 
						 
			        END--END ENTITY
			        ELSE 
                        BEGIN --UTTERANCE
	                        IF(@Model = 'utterance')
	                        BEGIN
	                         IF(@Key = '*')
							  UPDATE U SET U.[StatusCode] = @StatusCode, U.[Status] = @Status FROM [dbo].[Utterance] U JOIN [dbo].[NLU] N 
							  ON (U.[VCC] = N.[VCC] AND U.[AppId] = N.[AppId]) WHERE U.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND U.[Status] <> 4
							 ELSE
							 UPDATE [dbo].[Utterance] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [Id] = @key 
	                       
	                         END 
                      
						 
	
			             END--UTTERANCE
			       
			         
			    END--ENTITY
			    
		  
		  END -- INTENT
    END--NLU

	SELECT 1 AS result

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetEvaluationReviewCommitments]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationReviewCommitments] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	SELECT ER.[EvaluationPlanId]										'evaluationPlanId',
			ERC.[ID]													'id',
			AEP.[Score]													'score',
			ER.[SupervisorId]											'supervisorId',
			CONCAT(U2.[FirstName], ' ', ISNULL(U2.[LastName], ''))		'supervisorName',
			ERC.[LargeInteractionId]									'largeInteractionId',
			ERC.[AgentId]												'agentId',
			CONCAT(U1.[FirstName], ' ', ISNULL(U1.[LastName], ''))		'agentName',
			ERC.[Commitment]											'commitment',
			ERC.[CreatedDate]											'eventDate',
			ERC.[CreatedDate]											'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		INNER JOIN [dbo].[EvaluationReview] ER (NOLOCK)
			ON ER.[VCC] = ERC.[VCC]
				AND ER.[Id] = ERC.[EvaluationReviewId]
		INNER JOIN [dbo].[User] U1 (NOLOCK)
			ON U1.[VCC] = ERC.[VCC]
				AND U1.[ID] = ERC.[AgentId]
		INNER JOIN [dbo].[User] U2 (NOLOCK)
			ON U1.[VCC] = ERC.[VCC]
				AND U2.[ID] = ER.[SupervisorId]
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			ON AEP.[Instance] = ERC.[VCC]
				AND AEP.[IdEvaluationPlan] = ER.[EvaluationPlanId]
				AND AEP.[IdInteraction] = ER.[InteractionId]
				AND AEP.[IdAuditor] = ER.[SupervisorId]
				AND AEP.[IdAgent] = ERC.[AgentId]
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] =  ISNULL(@EvaluationPlanId, ER.[EvaluationPlanId])
			AND ER.[InteractionId] = ISNULL(@InteractionId, ER.[InteractionId])
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationReview]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationReview] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW
	SELECT ER.[VCC]													'vcc',
			ER.[Id]													'id',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	EXEC [dbo].[GetEvaluationReviewCommitments] @VCC, @EvaluationPlanId, @InteractionId, @SupervisorId, @AgentId
	/*
	SELECT ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[SupervisorId]										'supervisorId',
			ERC.[LargeInteractionId]								'largeInteractionId',
			ERC.[AgentId]											'agentId',
			ERC.[Commitment]										'commitment',
			ERC.[CreatedDate]										'eventDate',
			ERC.[CreatedDate]										'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		INNER JOIN [dbo].[EvaluationReview] ER (NOLOCK)
			ON ER.[VCC] = ERC.[VCC]
				AND ER.[Id] = ERC.[EvaluationReviewId]
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC
	*/
	
	SET NOCOUNT OFF
END
GO
PRINT N'Actualizando [dbo].[SaveVcc]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveVcc]';


GO
PRINT N'Actualización completada.';


GO
